@@ -1,4 +1,4 @@
-class Document(object):
+class Document:
     def __init__(self, input_file=None):
         self.filepath = None
         self.filename = None
@@ -11,6 +11,7 @@ class Document(object):
         self.checklist = {}
 
     def request(self, *args):
+        """Make request to the product endpoint"""
         raise NotImplementedError()
 
     def _checklist(self, *args):
@@ -20,4 +21,5 @@ class Document(object):
         pass
 
     def all_checks(self):
+        """Return all checks"""
         return all(self.checklist)
