@@ -1,4 +1,3 @@
-from mindee.benchmark import Benchmark
 from mindee.documents import Document
 from mindee.fields import Field
 from mindee.fields.date import Date
@@ -6,26 +5,25 @@ from mindee.fields.amount import Amount
 from mindee.fields.locale import Locale
 from mindee.fields.orientation import Orientation
 from mindee.fields.tax import Tax
-from mindee.http import request
-import os
+from mindee.http import make_api_request, make_predict_url
 
 
 class Receipt(Document):
     def __init__(
-            self,
-            api_prediction=None,
-            input_file=None,
-            locale=None,
-            total_incl=None,
-            date=None,
-            category=None,
-            merchant_name=None,
-            time=None,
-            taxes=None,
-            orientation=None,
-            total_tax=None,
-            total_excl=None,
-            page_n=0
+        self,
+        api_prediction=None,
+        input_file=None,
+        locale=None,
+        total_incl=None,
+        date=None,
+        category=None,
+        merchant_name=None,
+        time=None,
+        taxes=None,
+        orientation=None,
+        total_tax=None,
+        total_excl=None,
+        page_n=0,
     ):
         """
         :param api_prediction: Raw prediction from HTTP response
@@ -58,18 +56,34 @@ class Receipt(Document):
             self.build_from_api_prediction(api_prediction, page_n=page_n)
         else:
             self.locale = Locale({"value": locale}, value_key="value", page_n=page_n)
-            self.total_incl = Amount({"value": total_incl}, value_key="value", page_n=page_n)
+            self.total_incl = Amount(
+                {"value": total_incl}, value_key="value", page_n=page_n
+            )
             self.date = Date({"value": date}, value_key="value", page_n=page_n)
             self.category = Field({"value": category}, value_key="value", page_n=page_n)
-            self.merchant_name = Field({"value": merchant_name}, value_key="value", page_n=page_n)
+            self.merchant_name = Field(
+                {"value": merchant_name}, value_key="value", page_n=page_n
+            )
             self.time = Field({"value": time}, value_key="value", page_n=page_n)
             if taxes is not None:
                 self.taxes = [
-                    Tax({"value": t[0], "rate": t[1]}, page_n=page_n, value_key="value", rate_key="rate")
-                    for t in taxes]
-            self.orientation = Orientation({"value": orientation}, value_key="value", page_n=page_n)
-            self.total_tax = Amount({"value": total_tax}, value_key="value", page_n=page_n)
-            self.total_excl = Amount({"value": total_excl}, value_key="value", page_n=page_n)
+                    Tax(
+                        {"value": t[0], "rate": t[1]},
+                        page_n=page_n,
+                        value_key="value",
+                        rate_key="rate",
+                    )
+                    for t in taxes
+                ]
+            self.orientation = Orientation(
+                {"value": orientation}, value_key="value", page_n=page_n
+            )
+            self.total_tax = Amount(
+                {"value": total_tax}, value_key="value", page_n=page_n
+            )
+            self.total_excl = Amount(
+                {"value": total_excl}, value_key="value", page_n=page_n
+            )
 
         # Invoke Document constructor
         super(Receipt, self).__init__(input_file)
@@ -80,27 +94,29 @@ class Receipt(Document):
         # Reconstruct extra fields
         self._reconstruct()
 
-    def __str__(self):
-        return "-----Receipt data-----\n" \
-               "Filename: %s\n" \
-               "Total amount: %s \n" \
-               "Date: %s\n" \
-               "Category: %s\n" \
-               "Time: %s\n" \
-               "Merchant name: %s\n" \
-               "Taxes: %s\n" \
-               "Total taxes: %s\n" \
-               "----------------------" % \
-               (
-                   self.filename,
-                   self.total_incl.value,
-                   self.date.value,
-                   self.category.value,
-                   self.time.value,
-                   self.merchant_name.value,
-                   " - ".join([str(t) for t in self.taxes]),
-                   self.total_tax.value
-               )
+    def __str__(self) -> str:
+        return (
+            "-----Receipt data-----\n"
+            "Filename: %s\n"
+            "Total amount: %s \n"
+            "Date: %s\n"
+            "Category: %s\n"
+            "Time: %s\n"
+            "Merchant name: %s\n"
+            "Taxes: %s\n"
+            "Total taxes: %s\n"
+            "----------------------"
+            % (
+                self.filename,
+                self.total_incl.value,
+                self.date.value,
+                self.category.value,
+                self.time.value,
+                self.merchant_name.value,
+                " - ".join([str(t) for t in self.taxes]),
+                self.total_tax.value,
+            )
+        )
 
     def build_from_api_prediction(self, api_prediction, page_n=0):
         """
@@ -109,18 +125,33 @@ class Receipt(Document):
         :return: (void) set the object attributes with api prediction values
         """
         self.locale = Locale(api_prediction["locale"], page_n=page_n)
-        self.total_incl = Amount(api_prediction["total_incl"], value_key="value", page_n=page_n)
+        self.total_incl = Amount(
+            api_prediction["total_incl"], value_key="value", page_n=page_n
+        )
         self.date = Date(api_prediction["date"], value_key="value", page_n=page_n)
         self.category = Field(api_prediction["category"], page_n=page_n)
-        self.merchant_name = Field(api_prediction["supplier"], value_key="value", page_n=page_n)
+        self.merchant_name = Field(
+            api_prediction["supplier"], value_key="value", page_n=page_n
+        )
         self.time = Field(api_prediction["time"], value_key="value", page_n=page_n)
         self.taxes = [
-            Tax(tax_prediction, page_n=page_n, value_key="value", rate_key="rate", code_key="code")
-            for tax_prediction in api_prediction["taxes"]]
+            Tax(
+                tax_prediction,
+                page_n=page_n,
+                value_key="value",
+                rate_key="rate",
+                code_key="code",
+            )
+            for tax_prediction in api_prediction["taxes"]
+        ]
         if str(page_n) != "-1":
             self.orientation = Orientation(api_prediction["orientation"], page_n=page_n)
-        self.total_tax = Amount({"value": None, "probability": 0.}, value_key="value", page_n=page_n)
-        self.total_excl = Amount({"value": None, "probability": 0.}, value_key="value", page_n=page_n)
+        self.total_tax = Amount(
+            {"value": None, "probability": 0.0}, value_key="value", page_n=page_n
+        )
+        self.total_excl = Amount(
+            {"value": None, "probability": 0.0}, value_key="value", page_n=page_n
+        )
 
     @staticmethod
     def compare(receipt=None, ground_truth=None):
@@ -139,29 +170,24 @@ class Receipt(Document):
         # Compute Accuracy metrics
         metrics.update(Receipt.compute_accuracy(receipt, ground_truth))
 
-        # Compute precision metrics
-        metrics.update(Receipt.compute_precision(receipt, ground_truth))
-
         return metrics
 
     @staticmethod
     def request(
-            input_file,
-            base_url,
-            expense_receipt_token=None,
-            version="3",
-            include_words=False
+        input_file,
+        expense_receipt_token,
+        version="3",
+        include_words=False,
     ):
         """
         Make request to expense_receipts endpoint
         :param input_file: Input object
-        :param base_url: API base URL
         :param expense_receipt_token: Expense_receipts API token
         :param include_words: Include Mindee vision words in http_response
         :param version: API version
         """
-        url = os.path.join(base_url, "expense_receipts", "v" + version, "predict")
-        return request(url, input_file, expense_receipt_token, include_words)
+        url = make_predict_url("expense_receipts", version)
+        return make_api_request(url, input_file, expense_receipt_token, include_words)
 
     def _checklist(self):
         """
@@ -202,12 +228,15 @@ class Receipt(Document):
         # Crate epsilon
         eps = 1 / (100 * total_vat)
 
-        if self.total_incl.value * (1 - eps) - 0.02 <= reconstructed_total <= self.total_incl.value * (
-                1 + eps) + 0.02:
+        if (
+            self.total_incl.value * (1 - eps) - 0.02
+            <= reconstructed_total
+            <= self.total_incl.value * (1 + eps) + 0.02
+        ):
             for tax in self.taxes:
                 tax.probability = 1
-            self.total_tax.probability = 1.
-            self.total_incl.probability = 1.
+            self.total_tax.probability = 1.0
+            self.total_incl.probability = 1.0
             return True
         else:
             return False
@@ -222,7 +251,8 @@ class Receipt(Document):
         if len(self.taxes) and self.total_incl.value is not None:
             total_excl = {
                 "value": self.total_incl.value - Field.array_sum(self.taxes),
-                "probability": Field.array_probability(self.taxes) * self.total_incl.probability
+                "probability": Field.array_probability(self.taxes)
+                * self.total_incl.probability,
             }
             self.total_excl = Amount(total_excl, value_key="value", reconstructed=True)
 
@@ -234,11 +264,15 @@ class Receipt(Document):
         """
         if len(self.taxes) and self.total_tax.value is None:
             total_tax = {
-                "value": sum([tax.value if tax.value is not None else 0 for tax in self.taxes]),
-                "probability": Field.array_probability(self.taxes)
+                "value": sum(
+                    [tax.value if tax.value is not None else 0 for tax in self.taxes]
+                ),
+                "probability": Field.array_probability(self.taxes),
             }
             if total_tax["value"] > 0:
-                self.total_tax = Amount(total_tax, value_key="value", reconstructed=True)
+                self.total_tax = Amount(
+                    total_tax, value_key="value", reconstructed=True
+                )
 
     @staticmethod
     def compute_accuracy(receipt, ground_truth):
@@ -254,27 +288,3 @@ class Receipt(Document):
             "__acc__total_tax": ground_truth.total_tax == receipt.total_tax,
             "__acc__taxes": Tax.compare_arrays(receipt.taxes, ground_truth.taxes),
         }
-
-    @staticmethod
-    def compute_precision(receipt, ground_truth):
-        """
-        :param receipt: Receipt object to compare
-        :param ground_truth: Ground truth Receipt object
-        :return: Precision metrics
-        """
-        precisions = {
-            "__pre__total_incl": Benchmark.scalar_precision_score(
-                receipt.total_incl, ground_truth.total_incl),
-            "__pre__total_excl": Benchmark.scalar_precision_score(
-                receipt.total_excl, ground_truth.total_excl),
-            "__pre__receipt_date": Benchmark.scalar_precision_score(
-                receipt.date, ground_truth.date),
-            "__pre__total_tax": Benchmark.scalar_precision_score(
-                receipt.total_tax, ground_truth.total_tax)}
-
-        if len(receipt.taxes) == 0:
-            precisions["__pre__taxes"] = None
-        else:
-            precisions["__pre__taxes"] = Tax.compare_arrays(receipt.taxes, ground_truth.taxes)
-
-        return precisions
