@@ -3,8 +3,8 @@ from mindee.fields.orientation import Orientation
 
 def test_constructor():
     field_dict = {
-        'degrees': 90,
-        'probability': 0.1,
+        "degrees": 90,
+        "probability": 0.1,
     }
     orientation = Orientation(field_dict)
     assert orientation.value == 90
@@ -12,8 +12,8 @@ def test_constructor():
 
 def test_not_number():
     field_dict = {
-        'degrees': "aze",
-        'probability': 0.1,
+        "degrees": "aze",
+        "probability": 0.1,
     }
     orientation = Orientation(field_dict)
     assert orientation.value == 0
@@ -21,8 +21,8 @@ def test_not_number():
 
 def test_not_90():
     field_dict = {
-        'degrees': 255,
-        'probability': 0.1,
+        "degrees": 255,
+        "probability": 0.1,
     }
     orientation = Orientation(field_dict)
     assert orientation.value == 0
